@@ -31,7 +31,7 @@ from calibre.utils.date import utcnow
 from calibre.utils.filenames import ascii_filename
 from calibre.utils.https import get_https_resource_securely, HTTPError
 from calibre.utils.icu import numeric_sort_key as sort_key
-from calibre.utils.magick import create_canvas, Image
+from calibre.utils.img import image_from_data, Canvas
 from calibre.utils.zipfile import ZipFile, ZIP_STORED
 from calibre.utils.filenames import atomic_rename
 from lzma.xz import compress, decompress
@@ -153,28 +153,26 @@ def default_cover_icons(cols=5):
 def create_cover(report, icons=(), cols=5, size=60, padding=8):
     icons = icons or tuple(default_cover_icons(cols))
     rows = int(math.ceil(len(icons) / cols))
-    canvas = create_canvas(cols * (size + padding), rows * (size + padding), '#eeeeee')
-    y = -size - padding // 2
-    x = 0
-    for i, icon in enumerate(icons):
-        if i % cols == 0:
-            y += padding + size
-            x = padding // 2
-        else:
-            x += size + padding
-        if report and icon in report.name_map:
-            ipath = os.path.join(report.path, report.name_map[icon])
-        else:
-            ipath = I(icon, allow_user_override=False)
-        img = Image()
-        with open(ipath, 'rb') as f:
-            img.load(f.read())
-        scaled, nwidth, nheight = fit_image(img.size[0], img.size[1], size, size)
-        img.size = nwidth, nheight
-        dx = (size - nwidth) // 2
-        canvas.compose(img, x + dx, y)
-
-    return canvas.export('JPEG')
+    with Canvas(cols * (size + padding), rows * (size + padding), bgcolor='#eee') as canvas:
+        y = -size - padding // 2
+        x = 0
+        for i, icon in enumerate(icons):
+            if i % cols == 0:
+                y += padding + size
+                x = padding // 2
+            else:
+                x += size + padding
+            if report and icon in report.name_map:
+                ipath = os.path.join(report.path, report.name_map[icon])
+            else:
+                ipath = I(icon, allow_user_override=False)
+            with lopen(ipath, 'rb') as f:
+                img = image_from_data(f.read())
+            scaled, nwidth, nheight = fit_image(img.width(), img.height(), size, size)
+            img = img.scaled(nwidth, nheight, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
+            dx = (size - nwidth) // 2
+            canvas.compose(img, x + dx, y)
+    return canvas.export()
 
 def verify_theme(report):
     must_use_qt()
